
.. autosummary::
    :toctree: _source/
    
################################
Citing PowNet
################################

If you use PowNet in your work, we kindly ask that you cite the following publication. 
Citing the software helps acknowledge the effort involved in its development
and allows us to track its usage.


**Primary Reference:**

If you are using the latest version of PowNet, please cite the following publication: ::

  @article{bunnak2025bridging,
    title={Bridging theory and practice: Efficiently solving the unit commitment problem in production cost models},
    author={Bunnak, Phumthep and Coniglio, Stefano and Galelli, Stefano},
    journal={Energy},
    volume={322},
    pages={135454},
    year={2025},
    publisher={Elsevier}
    doi={https://doi.org/10.1016/j.energy.2025.135454}
  }


**PowNet Version before 2023**

If you are using a version of PowNet before 2023, please cite the following publication: ::

  @article{chowdhury2020pownet,
    title={PowNet: a network-constrained unit commitment/economic dispatch model for large-scale power systems analysis},
    author={Chowdhury, AFM Kamal and Kern, Jordan and Dang, Thanh Duc and Galelli, Stefano},
    journal={Journal of Open Research Software},
    volume={8},
    number={1},
    year={2020}
  }
